==> volcano-model-v1beta1-6.3.1-sources.jar: io/fabric8/volcano/scheduling/v1beta1/PodGroupStatusFluent.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodGroupStatusFluent<A extends PodGroupStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,PodGroupCondition item);
  public A setToConditions(Integer index,PodGroupCondition item);
  public A addToConditions(io.fabric8.volcano.scheduling.v1beta1.PodGroupCondition... items);
  public A addAllToConditions(Collection<PodGroupCondition> items);
  public A removeFromConditions(io.fabric8.volcano.scheduling.v1beta1.PodGroupCondition... items);
  public A removeAllFromConditions(Collection<PodGroupCondition> items);
  public A removeMatchingFromConditions(Predicate<PodGroupConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodGroupCondition> getConditions();
  public List<PodGroupCondition> buildConditions();
  public PodGroupCondition buildCondition(Integer index);
  public PodGroupCondition buildFirstCondition();
  public PodGroupCondition buildLastCondition();
  public PodGroupCondition buildMatchingCondition(Predicate<PodGroupConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<PodGroupConditionBuilder> predicate);
  public A withConditions(List<PodGroupCondition> conditions);
  public A withConditions(io.fabric8.volcano.scheduling.v1beta1.PodGroupCondition... conditions);
  public Boolean hasConditions();
  public PodGroupStatusFluent.ConditionsNested<A> addNewCondition();
  public PodGroupStatusFluent.ConditionsNested<A> addNewConditionLike(PodGroupCondition item);
  public PodGroupStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,PodGroupCondition item);
  public PodGroupStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public PodGroupStatusFluent.ConditionsNested<A> editFirstCondition();
  public PodGroupStatusFluent.ConditionsNested<A> editLastCondition();
  public PodGroupStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<PodGroupConditionBuilder> predicate);
  public Integer getFailed();
  public A withFailed(Integer failed);
  public Boolean hasFailed();
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public Integer getRunning();
  public A withRunning(Integer running);
  public Boolean hasRunning();
  public Integer getSucceeded();
  public A withSucceeded(Integer succeeded);
  public Boolean hasSucceeded();
  public interface ConditionsNested<N> extends Nested<N>,PodGroupConditionFluent<PodGroupStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> volcano-model-v1beta1-6.7.0-sources.jar: io/fabric8/volcano/scheduling/v1beta1/PodGroupStatusFluent.java <==
package io.fabric8.volcano.scheduling.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodGroupStatusFluent<A extends PodGroupStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,PodGroupCondition item);
  public A setToConditions(int index,PodGroupCondition item);
  public A addToConditions(io.fabric8.volcano.scheduling.v1beta1.PodGroupCondition... items);
  public A addAllToConditions(Collection<PodGroupCondition> items);
  public A removeFromConditions(io.fabric8.volcano.scheduling.v1beta1.PodGroupCondition... items);
  public A removeAllFromConditions(Collection<PodGroupCondition> items);
  public A removeMatchingFromConditions(Predicate<PodGroupConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PodGroupCondition> getConditions();
  public List<PodGroupCondition> buildConditions();
  public PodGroupCondition buildCondition(int index);
  public PodGroupCondition buildFirstCondition();
  public PodGroupCondition buildLastCondition();
  public PodGroupCondition buildMatchingCondition(Predicate<PodGroupConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<PodGroupConditionBuilder> predicate);
  public A withConditions(List<PodGroupCondition> conditions);
  public A withConditions(io.fabric8.volcano.scheduling.v1beta1.PodGroupCondition... conditions);
  public Boolean hasConditions();
  public PodGroupStatusFluent.ConditionsNested<A> addNewCondition();
  public PodGroupStatusFluent.ConditionsNested<A> addNewConditionLike(PodGroupCondition item);
  public PodGroupStatusFluent.ConditionsNested<A> setNewConditionLike(int index,PodGroupCondition item);
  public PodGroupStatusFluent.ConditionsNested<A> editCondition(int index);
  public PodGroupStatusFluent.ConditionsNested<A> editFirstCondition();
  public PodGroupStatusFluent.ConditionsNested<A> editLastCondition();
  public PodGroupStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<PodGroupConditionBuilder> predicate);
  public Integer getFailed();
  public A withFailed(Integer failed);
  public Boolean hasFailed();
  public String getPhase();
  public A withPhase(String phase);
  public Boolean hasPhase();
  public Integer getRunning();
  public A withRunning(Integer running);
  public Boolean hasRunning();
  public Integer getSucceeded();
  public A withSucceeded(Integer succeeded);
  public Boolean hasSucceeded();
  public interface ConditionsNested<N> extends Nested<N>,PodGroupConditionFluent<PodGroupStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
